@@ -24,6 +24,7 @@ from tacker.common import utils
 from tacker.db import api as db_api
 from tacker.db.db_sqlalchemy import api
 from tacker.db.db_sqlalchemy import models
+from tacker.db import sqlalchemyutils
 from tacker import objects
 from tacker.objects import base
 from tacker.objects import common
@@ -49,6 +50,7 @@ def _vnf_lcm_op_occ_create(context, values):
         'changed_info': values.changed_info,
         'changed_ext_connectivity': values.changed_ext_connectivity,
         'error_point': values.error_point,
+        'tenant_id': values.tenant_id,
     }
     if 'grant_id' in values:
         fields['grant_id'] = values.grant_id
@@ -56,7 +58,7 @@ def _vnf_lcm_op_occ_create(context, values):
         fields['operation_params'] = values.operation_params
 
     context.session.execute(
-        models.VnfLcmOpOccs.__table__.insert(None),
+        models.VnfLcmOpOccs.__table__.insert(),
         fields)
 
 
@@ -150,6 +152,19 @@ def _vnf_lcm_op_occs_get_by_filters(context, read_deleted=None,
     return query.all()
 
 
+@db_api.context_manager.reader
+def _vnf_lcm_op_occs_get_by_filters_query(context, read_deleted=None,
+                                    filters=None):
+
+    query = api.model_query(context, models.VnfLcmOpOccs,
+                            read_deleted=read_deleted, project_only=True)
+
+    if filters:
+        query = common.apply_filters(query, filters)
+
+    return query
+
+
 @db_api.context_manager.reader
 def _vnf_notify_get_by_id(context, vnf_instance_id, columns_to_join=None):
 
@@ -242,7 +257,8 @@ class VnfLcmOpOcc(base.TackerObject, base.TackerObjectDictCompat,
             'VnfInfoModifications', nullable=True, default=None),
         'changed_ext_connectivity': fields.ListOfObjectsField(
             'ExtVirtualLinkInfo', nullable=True, default=[]),
-        'error_point': fields.IntegerField(nullable=True, default=0)
+        'error_point': fields.IntegerField(nullable=True, default=0),
+        'tenant_id': fields.StringField(nullable=False)
     }
 
     ALL_ATTRIBUTES = {
@@ -367,6 +383,7 @@ class VnfLcmOpOcc(base.TackerObject, base.TackerObjectDictCompat,
         changed_info = data_dict.get('changed_info')
         changed_ext_connectivity = data_dict.get('changed_ext_connectivity')
         error_point = data_dict.get('error_point')
+        tenant_id = data_dict.get('tenant_id')
 
         obj = cls(operation_state=operation_state,
                   state_entered_time=state_entered_time,
@@ -381,7 +398,8 @@ class VnfLcmOpOcc(base.TackerObject, base.TackerObjectDictCompat,
                   resource_changes=resource_changes,
                   changed_info=changed_info,
                   changed_ext_connectivity=changed_ext_connectivity,
-                  error_point=error_point
+                  error_point=error_point,
+                  tenant_id=tenant_id
                   )
 
         return obj
@@ -480,6 +498,19 @@ class VnfLcmOpOccList(ovoo_base.ObjectListBase, base.TackerObject):
             context, read_deleted=read_deleted, filters=filters)
         return _make_vnf_lcm_op_occs_list(context, cls(), db_vnf_lcm_op_occs)
 
+    @base.remotable_classmethod
+    def get_by_marker_filter(cls, context, limit,
+            marker_obj, filters=None, read_deleted=None):
+        query = _vnf_lcm_op_occs_get_by_filters_query(
+            context, read_deleted=read_deleted, filters=filters)
+        query = sqlalchemyutils.paginate_query(query,
+            model=models.VnfLcmOpOccs,
+            limit=limit,
+            sorts=[['id', 'asc']],
+            marker_obj=marker_obj)
+        db_vnf_lcm_op_occs = query.all()
+        return _make_vnf_lcm_op_occs_list(context, cls(), db_vnf_lcm_op_occs)
+
 
 @base.TackerObjectRegistry.register
 class ResourceChanges(base.TackerObject,
