@@ -38,11 +38,17 @@ LOG = logging.getLogger(__name__)
 _ENFORCER = None
 ADMIN_CTX_POLICY = 'context_is_admin'
 
-# TODO(gmann): Remove setting the default value of config policy_file
-# once oslo_policy change the default value to 'policy.yaml'.
-# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+# TODO(gmann): Remove setting the default value of config options:
+# - 'policy_file' once oslo_policy change their default value to what is
+# overridden here.
+# - 'enforce_scope', and 'enforce_new_defaults' once cinder is ready with the
+# new RBAC (oslo_policy enable them by default)
 DEFAULT_POLICY_FILE = 'policy.yaml'
-opts.set_defaults(cfg.CONF, DEFAULT_POLICY_FILE)
+opts.set_defaults(
+    cfg.CONF,
+    DEFAULT_POLICY_FILE,
+    enforce_scope=False,
+    enforce_new_defaults=False)
 
 
 def reset():
@@ -52,17 +58,26 @@ def reset():
         _ENFORCER = None
 
 
-def init(conf=cfg.CONF, policy_file=None):
+def init(conf=cfg.CONF, policy_file=None, suppress_deprecation_warnings=False):
     """Init an instance of the Enforcer class."""
 
     global _ENFORCER
     if not _ENFORCER:
         _ENFORCER = policy.Enforcer(conf, policy_file=policy_file)
+        # NOTE(gmann): Explicitly disable the warnings for policies
+        # changing their default check_str. During policy-defaults-refresh
+        # work, all the policy defaults have been changed and warning for
+        # each policy started filling the logs limit for various tool.
+        # Once we move to new defaults only world then we can enable these
+        # warning again.
+        _ENFORCER.suppress_default_change_warnings = True
+        if suppress_deprecation_warnings:
+            _ENFORCER.suppress_deprecation_warnings = True
         register_rules(_ENFORCER)
         _ENFORCER.load_rules()
 
 
-def _pre_enhanced_policy_check(target, credentials):
+def _pre_enhanced_policy_check(target, credentials, target_chk=True):
     """Preprocesses target and credentials for enhanced tacker policy.
 
     This method does the following things:
@@ -90,14 +105,28 @@ def _pre_enhanced_policy_check(target, credentials):
             'vendor': ['*', 'company_A'],
             'tenant: ['*', 'default']
         }
-    2) Convert special value `all` to the corresponding attribute value in
+
+    2) Check whether using special role(ex: `all`) in target
+    As not assume using such in the further procedure, this method return here
+    in case check is NG.
+    However, once a object with the special role set as an attribute has been
+    registered, this check will prevent access to that object.
+    Therefore, for only user who has credentials with admin role or special
+    role(ex: `Tenant_all`) this check is skipped.
+
+    3) Convert special value `all` to the corresponding attribute value in
     target.
 
     :param target: a dictionary of the attributes of the object
         being accessed.
     :param credentials: The information about the user performing the action.
+    :param target_chk: boolean
+        True: execute check of 2)
+        False: skip check of 2)
     :return tgt: The preprocessed target is returned.
     :return user_attrs: The preprocessed credentials is returned.
+    :raises tacker.common.exceptions.PolicyTargetCheckError
+        if check of 2) is NG
     """
     if not cfg.CONF.oslo_policy.enhanced_tacker_policy:
         return target, credentials
@@ -109,6 +138,7 @@ def _pre_enhanced_policy_check(target, credentials):
 
     LOG.debug(f'target: {target}')
 
+    special_roles = {'area': r'all@\w+', 'vendor': 'all', 'tenant': 'all'}
     convert_map = {
         'area_': 'area',
         'vendor_': 'vendor',
@@ -119,7 +149,7 @@ def _pre_enhanced_policy_check(target, credentials):
         'vendor': ['*'],
         'tenant': ['*']
     }
-    # Convert special roles to enhanced policy attributes in credentials.
+    # 1) Convert special roles to enhanced policy attributes in credentials.
     for role in credentials.get('roles'):
         role = role.lower()
         for prefix, key in convert_map.items():
@@ -128,9 +158,33 @@ def _pre_enhanced_policy_check(target, credentials):
                 if attr:
                     user_attrs[key].append(attr)
 
+    # 2) Check whether using special role(ex: `all`) in target,
+    if target_chk and not credentials.get('is_admin', False):
+        for k, v in tgt.items():
+            if (k in special_roles and
+                    re.match(special_roles[k], v)):
+                chk_all = False
+                # Not NG in case credentials has special role
+                for uv in user_attrs[k]:
+                    if re.match(special_roles[k], uv):
+                        # In case 'area':
+                        # OK case1 : credential is all@all and
+                        #   target is all@region_A
+                        # OK case2 : credential is all@region_A and
+                        #   target is all@region_A
+                        # NG case  : credential is all@region_A and
+                        #   target is all@region_B
+                        if k == 'area' and uv != 'all@all' and uv != v.lower():
+                            continue
+                        chk_all = True
+                if not chk_all:
+                    msg = f'`{v}` of {k} in target is special role'
+                    LOG.error(msg)
+                    raise exceptions.PolicyTargetCheckError(reason=msg)
+
     common_keys = user_attrs.keys() & tgt.keys()
 
-    # Convert special value `all` to the corresponding attribute value in
+    # 3) Convert special value `all` to the corresponding attribute value in
     # target.
     for key in common_keys:
         tgt[key] = tgt[key].lower()
@@ -138,10 +192,11 @@ def _pre_enhanced_policy_check(target, credentials):
         if tgt.get(key) == '*':
             continue
         to_remove = []
+        orig_attrs = copy.deepcopy(attrs)
         if 'area' == key:
             if not is_valid_area(tgt.get(key)):
                 continue
-            for attr in attrs:
+            for attr in orig_attrs:
                 if not is_valid_area(attr):
                     continue
                 if 'all@all' == attr:
@@ -168,7 +223,7 @@ def _pre_enhanced_policy_check(target, credentials):
                     #       'all@region_A' -> to be removed.
 
         else:
-            for attr in attrs:
+            for attr in orig_attrs:
                 if 'all' == attr:
                     # example:
                     #   target = {'vendor': 'company_A'}
@@ -188,15 +243,42 @@ def authorize(context, action, target, do_raise=True, exc=None):
 
     init()
     credentials = context.to_policy_values()
-    target, credentials = _pre_enhanced_policy_check(target, credentials)
+    # NOTE(gmann): For system, scope token, oslo.policy check
+    # for a key 'system' in creds. The oslo.context library uses
+    # `system_scope` instead. Because we are converting the context
+    # attribute to creds via context.to_policy_values which does not
+    # convert 'system_scope' key. There are two ways to solve this:
+    # 1. Pass full context to oslo.policy and their it convert this key
+    # but Tacker has special case of enhanced policy conversion
+    # (via _pre_enhanced_policy_check(), method which sets its own
+    # key in creds. So passing full context to oslo.policy make enhance
+    # policy conversion more complex.
+    # 2. Set 'system' key in creds explicitly. This is easy and more
+    # readable way.
+    if context.system_scope:
+        credentials['system'] = context.system_scope
     if not exc:
         exc = exceptions.PolicyNotAuthorized
+
+    try:
+        target, credentials = _pre_enhanced_policy_check(target, credentials)
+    except exceptions.PolicyTargetCheckError:
+        LOG.error('Policy check for %(action)s failed with target check '
+              '%(target)s', {'action': action, 'target': target})
+        raise exc(action=action)
+
     try:
         result = _ENFORCER.authorize(action, target, credentials,
                                      do_raise=do_raise, exc=exc, action=action)
     except policy.PolicyNotRegistered:
         with excutils.save_and_reraise_exception():
             LOG.error('Policy not registered')
+    except policy.InvalidScope:
+        LOG.debug('Policy check for %(action)s failed with scope check '
+                  '%(credentials)s',
+                  {'action': action,
+                   'credentials': credentials})
+        raise exc(action=action)
     except Exception:
         with excutils.save_and_reraise_exception():
             LOG.error('Policy check for %(action)s failed with credentials '
@@ -519,7 +601,12 @@ def check(context, action, target, plugin=None, might_not_exist=False,
             target.update({'area': area})
     if 'tenant_id' in target:
         target['project_id'] = target['tenant_id']
-    target, credentials = _pre_enhanced_policy_check(target, credentials)
+    try:
+        target, credentials = _pre_enhanced_policy_check(target, credentials)
+    except exceptions.PolicyTargetCheckError:
+        LOG.error('Policy check for %(action)s failed with target check '
+              '%(target)s', {'action': action, 'target': target})
+        return False
 
     result = _ENFORCER.enforce(match_rule,
                                target,
@@ -567,8 +654,21 @@ def enforce(context, action, target, plugin=None, pluralized=None,
             target.update({'area': area})
     if 'tenant_id' in target:
         target['project_id'] = target['tenant_id']
-    target, credentials = _pre_enhanced_policy_check(target, credentials)
 
+    # About target_chk:
+    # Set target_chk=False, as not execute target check.
+    # The reason is that matching with the behavior of other APIs
+    # that pass through the 'authorize' method.
+    # ex:
+    #   1 openstack vim register with area set special role
+    #     (this method is passed through, for policy check)
+    #     -> target_chk=True, policy check `NG`
+    #   2 instantiate with request parameter area set special role
+    #     (`authorize` method is passed through, for policy check)
+    #     -> target_chk=True, policy check `OK`
+    #   -> There is a difference in the behavior of 1 and 2
+    target, credentials = _pre_enhanced_policy_check(
+        target, credentials, target_chk=False)
     try:
         result = _ENFORCER.enforce(rule, target, credentials, action=action,
                                    do_raise=True, exc=exc)
