@@ -93,6 +93,10 @@ VNFM_OPTS = [
                help=_('Error message for Availability Zone reselection. '
                       'These configs are regular expressions to detect '
                       'error messages from OpenStack Heat.')),
+    cfg.BoolOpt('enable_rollback_stack',
+                default=False,
+                help=_('If True, enable rollback stack on resource create '
+                       'failure.')),
     # NOTE: This is for test use since it is convenient to be able to delete
     # under development.
     cfg.BoolOpt('test_enable_lcm_op_occ_delete',
@@ -126,7 +130,19 @@ VNFM_OPTS = [
     cfg.StrOpt('heat_ca_cert_file',
                default='',
                help=_('Specifies the root CA certificate to use when the '
-                      'heat_verify_cert option is True.'))
+                      'heat_verify_cert option is True.')),
+    cfg.StrOpt('tf_file_dir',
+             default='/var/lib/tacker/terraform',
+             help=_('Temporary directory for Terraform infra-driver to '
+                    'store terraform config files')),
+    cfg.BoolOpt('nova_verify_cert',
+                default=False,
+                help=_('Enable certificate verification during SSL/TLS '
+                       'communication to nova server.')),
+    cfg.StrOpt('nova_ca_cert_file',
+               default='',
+               help=_('Specifies the root CA certificate to use when the '
+                      'nova_verify_cert option is True.'))
 ]
 
 CONF.register_opts(VNFM_OPTS, 'v2_vnfm')
