@@ -50,16 +50,14 @@ def lcmocc_task_href(lcmocc_id, task, endpoint):
 
 
 def make_lcmocc_links(lcmocc, endpoint):
-    links = objects.VnfLcmOpOccV2_Links()
-    links.self = objects.Link(href=lcmocc_href(lcmocc.id, endpoint))
-    links.vnfInstance = objects.Link(
-        href=inst_utils.inst_href(lcmocc.vnfInstanceId, endpoint))
-    links.retry = objects.Link(
-        href=lcmocc_task_href(lcmocc.id, 'retry', endpoint))
-    links.rollback = objects.Link(
-        href=lcmocc_task_href(lcmocc.id, 'rollback', endpoint))
-    links.fail = objects.Link(
-        href=lcmocc_task_href(lcmocc.id, 'fail', endpoint))
+    links = {'self': {'href': lcmocc_href(lcmocc['id'], endpoint)}}
+    links['vnfInstance'] = {
+        'href': inst_utils.inst_href(lcmocc['vnfInstanceId'], endpoint)}
+    links['retry'] = {
+        'href': lcmocc_task_href(lcmocc['id'], 'retry', endpoint)}
+    links['rollback'] = {
+        'href': lcmocc_task_href(lcmocc['id'], 'rollback', endpoint)}
+    links['fail'] = {'href': lcmocc_task_href(lcmocc['id'], 'fail', endpoint)}
     # TODO(oda-g): add when implemented
     # links.grant
     # links.cancel
@@ -612,3 +610,21 @@ def check_lcmocc_in_progress(context, inst_id):
 def update_lcmocc_status(lcmocc, op_state):
     lcmocc.operationState = op_state
     lcmocc.stateEnteredTime = datetime.utcnow()
+
+
+def new_lcmocc(inst_id, operation, req_body,
+               op_state=fields.LcmOperationStateType.STARTING,
+               auto_invocation=False):
+    now = datetime.utcnow()
+    lcmocc = objects.VnfLcmOpOccV2(
+        id=uuidutils.generate_uuid(),
+        operationState=op_state,
+        stateEnteredTime=now,
+        startTime=now,
+        vnfInstanceId=inst_id,
+        operation=operation,
+        isAutomaticInvocation=auto_invocation,
+        isCancelPending=False,
+        operationParams=req_body)
+
+    return lcmocc
