@@ -28,6 +28,7 @@ from tacker.db.migration import migrate_to_v2
 from tacker.db.nfvo import nfvo_db
 from tacker.db.vnfm import vnfm_db
 from tacker import objects
+from tacker.sol_refactored.common import vnf_instance_utils as inst_utils
 from tacker.sol_refactored import objects as objects_v2
 from tacker.sol_refactored.objects.v2 import fields as fields_v2
 from tacker.tests.base import BaseTestCase
@@ -235,6 +236,7 @@ class TestDbMigrationToV2(SqlTestCase):
                        'key_type': 'fernet_key'})
         session.add(vim_db)
         session.add(vim_auth_db)
+        session.commit()
         return vim_db
 
     def _create_vnf_attributes(self, vnf_inst_id=None):
@@ -944,7 +946,7 @@ class TestDbMigrationToV2(SqlTestCase):
 
         _vnf_instance = objects.vnf_instance._vnf_instance_get_by_id(
             self.context,
-            vnf_id, columns_to_join=["instantiated_vnf_info"],
+            vnf_id, columns_to_join=[models.VnfInstance.instantiated_vnf_info],
             read_deleted="yes")
         self.assertEqual(_vnf_instance.deleted, 0)
         _vnf_info = _vnf_instance.instantiated_vnf_info
@@ -1025,15 +1027,15 @@ class TestDbMigrationToV2(SqlTestCase):
         # vimConnectionInfo
         vim_conn_info_v2 = vnf_instance_v2.vimConnectionInfo
         vim_conn_info_v1 = vnf_instance_v1.vim_connection_info
-        self.assertEqual(vim_conn_info_v2["vim0"].vimId,
+        self.assertEqual(vim_conn_info_v2["vim_0"].vimId,
                          vim_conn_info_v1[0].vim_id)
-        self.assertEqual(vim_conn_info_v2["vim0"].vimType,
+        self.assertEqual(vim_conn_info_v2["vim_0"].vimType,
                          vim_conn_info_v1[0].vim_type)
-        self.assertEqual(vim_conn_info_v2["vim0"].interfaceInfo,
+        self.assertEqual(vim_conn_info_v2["vim_0"].interfaceInfo,
                          vim_conn_info_v1[0].interface_info)
-        self.assertEqual(vim_conn_info_v2["vim0"].accessInfo,
+        self.assertEqual(vim_conn_info_v2["vim_0"].accessInfo,
                          vim_conn_info_v1[0].access_info)
-        self.assertEqual(vim_conn_info_v2["vim0"].extra,
+        self.assertEqual(vim_conn_info_v2["vim_0"].extra,
                          vim_conn_info_v1[0].extra)
 
         self.assertEqual(vnf_instance_v2.instantiationState,
@@ -1305,7 +1307,22 @@ class TestDbMigrationToV2(SqlTestCase):
                              vnfc_res_infos_v1[i].id)
             self.assertEqual(vnfc_info_v2.vnfcState, "STARTED")
 
-    def test_create_vnf_lcm_op_occ_v2(self):
+    @mock.patch.object(inst_utils, 'get_inst')
+    def test_create_vnf_lcm_op_occ_v2(self, mock_inst):
+        vim_connection_info = objects_v2.VimConnectionInfo.from_dict({
+            "vimId": uuidutils.generate_uuid(),
+            "vimType": "ETSINFV.OPENSTACK_KEYSTONE.V_3"
+        })
+        mock_inst.return_value = objects_v2.VnfInstanceV2(
+            id=uuidutils.generate_uuid(),
+            vnfdId=uuidutils.generate_uuid(),
+            vnfProvider='provider',
+            vnfProductName='product name',
+            vnfSoftwareVersion='software version',
+            vnfdVersion='vnfd version',
+            instantiationState='INSTANTIATED',
+            vimConnectionInfo={"vim_0": vim_connection_info}
+        )
         vnf_lcm_op_occs_v1 = self.vnf_lcm_op_occs
         vnf_lcm_op_occs_v2 = \
             migrate_to_v2.create_vnf_lcm_op_occs_v2(self.context,
