@@ -35,6 +35,7 @@ from tacker.objects import scale_vnf_request
 from tacker.objects.vim_connection import VimConnectionInfo
 from tacker.policies import vnf_lcm as vnf_lcm_policies
 from tacker.tests import constants
+from tacker.tests import utils as test_utils
 from tacker.tests import uuidsentinel
 from tacker import wsgi
 
@@ -255,6 +256,10 @@ def _instantiated_vnf_links(vnf_instance_id):
             '{endpoint}/vnflcm/v1/vnf_instances/{id}/terminate'.format(
                 endpoint=CONF.vnf_lcm.endpoint_url.rstrip("/"),
                 id=vnf_instance_id)},
+        "scale": {"href":
+            '{endpoint}/vnflcm/v1/vnf_instances/{id}/scale'.format(
+                endpoint=CONF.vnf_lcm.endpoint_url.rstrip("/"),
+                id=vnf_instance_id)},
         "heal": {"href":
             '{endpoint}/vnflcm/v1/vnf_instances/{id}/heal'.format(
                 endpoint=CONF.vnf_lcm.endpoint_url.rstrip("/"),
@@ -716,19 +721,6 @@ def get_vnfd_dict(image_path=None):
     return vnfd_dict
 
 
-def get_dummy_vnf_instance():
-    connection_info = get_dummy_vim_connection_info()
-    return {'created_at': '', 'deleted': False, 'deleted_at': None,
-            'id': 'fake_id', 'instantiated_vnf_info': None,
-            'instantiation_state': 'NOT_INSTANTIATED',
-            'tenant_id': 'fake_tenant_id', 'updated_at': '',
-            'vim_connection_info': [connection_info],
-            'vnf_instance_description': 'VNF Description',
-            'vnf_instance_name': 'test', 'vnf_product_name': 'Sample VNF',
-            'vnf_provider': 'Company', 'vnf_software_version': '1.0',
-            'vnfd_id': 'fake_vnfd_id', 'vnfd_version': '1.0'}
-
-
 def get_dummy_vim_connection_info():
     return {'access_info': {
         'auth_url': 'fake/url',
@@ -843,8 +835,8 @@ def _get_vnf(**updates):
         'instance_id': uuidsentinel.instance_id,
         'attributes': {
             "scale_group": '{"scaleGroupDict" : {"SP1": {"maxLevel" : 3}}}',
-            "heat_template": os.path.dirname(__file__) +
-            "/../../etc/samples/hot_lcm_template.yaml"}}
+            "heat_template": test_utils.test_etc_sample(
+                "hot_lcm_template.yaml")}}
 
     if updates:
         vnf_data.update(**updates)
@@ -1379,7 +1371,7 @@ def vnfd_dict_cnf(vdu_num=1):
             "type": "tosca.policies.nfv.VduInitialDelta",
             "properties": {
                 "initial_delta": {
-                    "number_of_instances": 0}},
+                    "number_of_instances": 1}},
             "targets": [f"VDU{i}"]}})
         policies.append({f"vdu{i}_scaling_aspect_deltas": {
             "type": "tosca.policies.nfv.VduScalingAspectDeltas",
@@ -1394,9 +1386,9 @@ def vnfd_dict_cnf(vdu_num=1):
             "properties": {
                 "levels": {
                     "instantiation_level_1": {
-                        "number_of_instances": 0},
+                        "number_of_instances": 1},
                     "instantiation_level_2": {
-                        "number_of_instances": 2}}},
+                        "number_of_instances": 3}}},
             "targets": [f"VDU{i}"]}})
         levels["instantiation_level_1"]["scale_info"] = {
             f"vdu{i}_aspect": {"scale_level": 0}}
@@ -2528,3 +2520,18 @@ def get_test_data_policy_vnf_instantiated(action, success_status_code):
     })
 
     return test_data
+
+
+def fake_extract_policy_infos():
+    return {
+        'inst_level_dict': {
+            'instantiation_level_1': {'vdu1_aspect': 0},
+            'instantiation_level_2': {'vdu1_aspect': 2}
+        },
+        'aspect_delta_dict': {'vdu1_aspect': {'delta_1': 1}},
+        'aspect_id_dict': {'vdu1_aspect': 'delta_1'},
+        'aspect_vdu_dict': {'vdu1_aspect': ['VDU1']},
+        'vdu_delta_dict': {'VDU1': 1},
+        'aspect_max_level_dict': {'vdu1_aspect': 2},
+        'default_inst_level_id': 'instantiation_level_1'
+    }
