@@ -530,7 +530,8 @@ def _get_vim_connection_info_from_vnf_req(vnf_instance, instantiate_vnf_req):
         vim_conn = objects.VimConnectionInfo(id=vim_connection.id,
             vim_id=vim_connection.vim_id, vim_type=vim_connection.vim_type,
             access_info=vim_connection.access_info,
-            interface_info=vim_connection.interface_info)
+            interface_info=vim_connection.interface_info,
+            extra=vim_connection.extra)
 
         vim_connection_obj_list.append(vim_conn)
 
@@ -1127,8 +1128,9 @@ def _convert_desired_capacity(inst_level_id, vnfd_dict, vdu):
     aspect_max_level_dict = {}
     desired_capacity = 1
 
-    tosca = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
-                                         yaml_dict_tpl=vnfd_dict)
+    tosca = tosca_template.ToscaTemplate(
+        parsed_params={}, a_file=False, yaml_dict_tpl=vnfd_dict,
+        local_defs=toscautils.tosca_tmpl_local_defs())
     tosca_policies = tosca.topology_template.policies
     default_inst_level_id = toscautils._extract_policy_info(
         tosca_policies, inst_level_dict,
@@ -1251,8 +1253,9 @@ def get_default_scale_status(context, vnf_instance, vnfd_dict):
     vnfd_dict = _get_vnfd_dict(context,
         vnf_instance.vnfd_id,
         vnf_instance.instantiated_vnf_info.flavour_id)
-    tosca = tosca_template.ToscaTemplate(parsed_params={}, a_file=False,
-                                         yaml_dict_tpl=vnfd_dict)
+    tosca = tosca_template.ToscaTemplate(
+        parsed_params={}, a_file=False, yaml_dict_tpl=vnfd_dict,
+        local_defs=toscautils.tosca_tmpl_local_defs())
     extract_policy_infos = get_extract_policy_infos(tosca)
 
     if extract_policy_infos['inst_level_dict'] is None:
@@ -1290,6 +1293,35 @@ def get_target_vdu_def_dict(extract_policy_infos, aspect_id, tosca):
     return vdu_def_dict
 
 
+def get_current_num_of_instances(extract_policy_infos,
+                                 aspect_id, scale_level):
+    delta_id = extract_policy_infos['aspect_id_dict'].get(aspect_id)
+    if delta_id is None:
+        raise exceptions.InvalidPoliciesDefinition(
+            param='step_deltas id in ScalingAspects')
+
+    # Get delta_num.
+    delta_num = extract_policy_infos['aspect_delta_dict'].get(
+        aspect_id, {}).get(delta_id)
+    if delta_num is None:
+        raise exceptions.InvalidPoliciesDefinition(
+            param='delta num in VduScalingAspectDeltas')
+
+    # Get initial_delta.
+    vdus = extract_policy_infos['aspect_vdu_dict'].get(aspect_id)
+    initial_delta = None
+    if vdus:
+        # NOTE: The current tacker implementation allows one target vdu
+        #       per aspect_id, so get the first vdu_id here.
+        initial_delta = extract_policy_infos['vdu_delta_dict'].get(vdus[0])
+
+    if initial_delta is None:
+        raise exceptions.InvalidPoliciesDefinition(
+            param='initial_delta num in VduInitialDelta')
+    # Calculate current number_of_instances.
+    return initial_delta + delta_num * scale_level
+
+
 def _get_changed_ext_connectivity(
         old_vnf_instance=None, new_vnf_instance=None):
 
