@@ -392,14 +392,19 @@ class VnfLcmDriver(abstract_driver.VnfInstanceAbstractDriver):
             vnf_instance.instantiated_vnf_info.scale_status = \
                 vnf_dict['scale_status']
         elif vnf_instance.instantiated_vnf_info:
-            default_scale_status = vnflcm_utils.\
-                get_default_scale_status(
-                    context=context,
-                    vnf_instance=vnf_instance,
+            if final_vnf_dict.get('scale_status'):
+                # 'scale_status' is stored during instantiate_vnf() in
+                # infra_driver, or it is stored in _respawn_vnf() for
+                # SOL003 heal.
+                vnf_instance.instantiated_vnf_info.scale_status = (
+                    final_vnf_dict['scale_status'])
+            else:
+                default_scale_status = vnflcm_utils.get_default_scale_status(
+                    context=context, vnf_instance=vnf_instance,
                     vnfd_dict=vnfd_dict)
-            if default_scale_status is not None:
-                vnf_instance.instantiated_vnf_info.scale_status = \
-                    default_scale_status
+                if default_scale_status is not None:
+                    vnf_instance.instantiated_vnf_info.scale_status = (
+                        default_scale_status)
 
         if vnf_dict['before_error_point'] <= EP.PRE_VIM_CONTROL:
             try:
@@ -534,16 +539,20 @@ class VnfLcmDriver(abstract_driver.VnfInstanceAbstractDriver):
         # Get vnf_instance from DB by vnf_instance_id
         vnf_instance_id = vnf_lcm_opoccs.get('vnf_instance_id')
         vnf_instance = objects.VnfInstance.get_by_id(context, vnf_instance_id)
-        vnfd_dict = vnflcm_utils.get_vnfd_dict(
-            context, vnf_instance.vnfd_id,
-            vnf_instance.instantiated_vnf_info.flavour_id)
 
-        # modify_information_start(context, vnf_instance)
-        self._mgmt_manager.invoke(
-            self._load_vnf_interface(
-                context, 'modify_information_start', vnf_instance, vnfd_dict),
-            'modify_information_start', context=context,
-            modify_vnf_request=None, vnf_instance=vnf_instance)
+        # In case NOT_INSTANTIATED, flavour and mgmt driver script is not
+        # specified yet, So, modify_information_start can't be executed
+        if vnf_instance.instantiation_state == 'INSTANTIATED':
+            vnfd_dict = vnflcm_utils.get_vnfd_dict(
+                context, vnf_instance.vnfd_id,
+                vnf_instance.instantiated_vnf_info.flavour_id)
+
+            # modify_information_start(context, vnf_instance)
+            self._mgmt_manager.invoke(
+                self._load_vnf_interface(context,
+                    'modify_information_start', vnf_instance, vnfd_dict),
+                'modify_information_start', context=context,
+                modify_vnf_request=None, vnf_instance=vnf_instance)
 
         # Get the old vnf package path according to vnfd_id
         old_vnf_package_path = vnflcm_utils.get_vnf_package_path(
@@ -564,34 +573,36 @@ class VnfLcmDriver(abstract_driver.VnfInstanceAbstractDriver):
         vim_connection_info = objects.VimConnectionInfo.obj_from_primitive(
             vim_info, context)
 
-        kwargs = {}
-        if vim_connection_info.vim_type == 'kubernetes':
-            # If the file path of ConfigMap/Secret is changed
-            cm_secret_paths = []
-            # Get the metadata from vnf_lcm_opoccs
-            operation_params = vnf_lcm_opoccs.get('operationParams')
-            if operation_params:
-                try:
-                    cm_secret_paths = (ast.literal_eval(operation_params)
-                                       .get('metadata', {})
-                                       .get('configmap_secret_paths', []))
-                except Exception as e:
-                    LOG.error('Invalid format operationParams')
-                    raise exceptions.InvalidInput(str(e))
-            # NOTE(fengyi): Please be careful not to modify the parameters
-            # in kwargs, because MgmtDriver will depend on the
-            # parameters here, you can add parameters, but do not
-            # modify the original, unless you know that your
-            # modification has no effect on other MgmtDrivers.
-            kwargs = {"old_vnf_package_path": old_vnf_package_path,
-                      "configmap_secret_paths": cm_secret_paths}
+        if vnf_instance.instantiation_state == 'INSTANTIATED':
+            kwargs = {}
+            if vim_connection_info.vim_type == 'kubernetes':
+                # If the file path of ConfigMap/Secret is changed
+                cm_secret_paths = []
+                # Get the metadata from vnf_lcm_opoccs
+                operation_params = vnf_lcm_opoccs.get('operationParams')
+                if operation_params:
+                    try:
+                        cm_secret_paths = (ast.literal_eval(operation_params)
+                                           .get('metadata', {})
+                                           .get('configmap_secret_paths', []))
+                    except Exception as e:
+                        LOG.error('Invalid format operationParams')
+                        raise exceptions.InvalidInput(str(e))
+                # NOTE(fengyi): Please be careful not to modify the parameters
+                # in kwargs, because MgmtDriver will depend on the
+                # parameters here, you can add parameters, but do not
+                # modify the original, unless you know that your
+                # modification has no effect on other MgmtDrivers.
+                kwargs = {"old_vnf_package_path": old_vnf_package_path,
+                          "configmap_secret_paths": cm_secret_paths}
+
+            self._mgmt_manager.invoke(
+                self._load_vnf_interface(context,
+                    'modify_information_end', vnf_instance, vnfd_dict),
+                'modify_information_end', context=context,
+                modify_vnf_request=None,
+                vnf_instance=vnf_instance, **kwargs)
 
-        self._mgmt_manager.invoke(
-            self._load_vnf_interface(
-                context, 'modify_information_end', vnf_instance, vnfd_dict),
-            'modify_information_end', context=context,
-            modify_vnf_request=None,
-            vnf_instance=vnf_instance, **kwargs)
         return updated_time
 
     @log.log
@@ -863,6 +874,13 @@ class VnfLcmDriver(abstract_driver.VnfInstanceAbstractDriver):
                     raise exceptions.VnfHealFailed(id=vnf_instance.id,
                         error=encodeutils.exception_to_unicode(exc))
 
+        if vnf_instance.instantiated_vnf_info.scale_status:
+            # Since the instantiated_vnf_info is initialized in subsequent
+            # processing, scale_status is stored to vnf_dict to preserve the
+            # scale status before SOL003 heal.
+            vnf_dict['scale_status'] = (vnf_instance.instantiated_vnf_info
+                                        .scale_status)
+
         # InstantiateVnfRequest is not stored in the db as it's mapped
         # to InstantiatedVnfInfo version object. Convert InstantiatedVnfInfo
         # version object to InstantiateVnfRequest so that vnf can be
@@ -1734,17 +1752,8 @@ class VnfLcmDriver(abstract_driver.VnfInstanceAbstractDriver):
                         'region_name'))
 
             else:
-                instance_id = vnf_instance.instantiated_vnf_info.instance_id
-                access_info = vim_connection_info.access_info
-                self._vnf_manager.invoke(vim_connection_info.vim_type,
-                    'delete', plugin=self, context=context,
-                    vnf_id=instance_id, auth_attr=access_info,
-                    vnf_instance=vnf_instance)
-
-                self._vnf_manager.invoke(vim_connection_info.vim_type,
-                    'delete_wait', plugin=self, context=context,
-                    vnf_id=instance_id, auth_attr=access_info,
-                    vnf_instance=vnf_instance)
+                self._delete_vnf_instance_resources(context, vnf_instance,
+                    vim_connection_info, update_instantiated_state=False)
 
         vnf_lcm_op_occs.error_point = EP.PRE_VIM_CONTROL
 
