@@ -7,7 +7,7 @@ class Machines < Array
       :private_ips, :public_ips, :ssh_forward_x11, :fwd_port_list
 
     def initialize(
-      hostname="controller", provider="virtualbox", box="ubuntu/focal64",
+      hostname="controller", provider="virtualbox", box="bento/ubuntu-22.04",
       nof_cpus=2, mem_size=4, disk_size=10,
       private_ips=["192.168.56.11"], public_ips=nil, ssh_forward_x11=false,
       fwd_port_list=nil)
